%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Data Analysis Examples for COMP_mu regression models, to        %%%
%%% accompany the paper "Mean-parametrized Conway-Maxwell-Poisson   %%%
%%% models for dispersed counts" by Alan Huang, School of           %%%
%%% Maths and Physics, the University of Queensland                 %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% fit model to full days absent dataset
% load DaysAbsentExample.mat first
xx = [intercept, gendermale, progAcademic, progVocational, math] ;
tic;
[beta, nu, lambda, maxloglik] = loglinear_comp(daysabs, xx) ;
toc;
beta
nu
maxloglik

% test whether Poisson regression is reasonable
% negative log-likelihood of Poisson fit is 1315.
LRT = 2*(maxloglik - -1315) ;
1-fcdf(LRT/1, 1, 314-6)

% test whether gender is a significant predictor
xx0 = [intercept, math, progAcademic, progVocational] ;
[beta0, nu0, lambda0, maxloglik0] = loglinear_comp(daysabs, xx0) ;
LRT = 2*(maxloglik-maxloglik0) ;
1-fcdf(LRT/1, 1, 314-6)
% borderline significant

% Probability integral plots for goodness-of-fit
comp_mu_pit(daysabs, lambda, nu) ;
title('(a) Days absent dataset') ;


%% fit model to full bids dataset
% load BidsExample.mat first
intercept = ones(126,1) ;
xx = [intercept, leglrest, rearest, finrest, whtknght, bidprem, insthold, size1, size1.^2, regulatn]
tic;
[beta, nu, lambda, maxloglik, se_beta] = loglinear_comp(numbids, xx) ;
toc;

% Probability integral plots for goodness-of-fit
comp_mu_pit(numbids, lambda, nu) ;
title('(b) Number of bids dataset') ;

%% fit model to full bolls dataset
% load CottonBollsExample.mat first

% fit all 5 models from paper

intercept = ones(125,1) ;
% one intercept, 5 linear terms and 5 quadratic terms for each of 5 states
% slope and intercept parametrisation
xx5 = [intercept, desvegetative, des2vegetative, desflowerbud, des2flowerbud, desblossom, des2blossom,  desfig,  des2fig,  descottonboll, des2cottonboll];
tic;
[beta5, nu5, lambda, maxloglik5, se_beta5, var_beta5] = loglinear_comp(nc, xx5) ;
time5 =toc;

% Probability integral plots for goodness-of-fit
comp_mu_pit(nc, lambda, nu5) ;
title('(c) Cotton bolls dataset') ;

% one intercept, 5 linear terms, one quadratic
xx4 = [intercept, des, des2, desflowerbud, desfig, desblossom, descottonboll];
tic;
[beta4, nu4, lambda, maxloglik4, se_beta4] = loglinear_comp(nc, xx4) ;
time4 = toc;

% one intercept, one linear term, one quadratic
xx3 = [intercept, des, des2];
tic;
[beta3, nu3, lambda, maxloglik3, se_beta3] = loglinear_comp(nc, xx3) ;
time3 = toc;

% one intercept, one linear term
xx2 = [intercept, des];
tic;
[beta2, nu2, lambda, maxloglik2, se_beta2] = loglinear_comp(nc, xx2) ;
time2 = toc;

% one intercept
xx1 = [intercept];
tic;
[beta1, nu1, lambda, maxloglik1, se_beta1] = loglinear_comp(nc, xx1) ;
time1 = toc;

% test between 5 nested models
LRT2 = 2*(maxloglik2-maxloglik1)
LRT3 = 2*(maxloglik3-maxloglik2)
LRT4 = 2*(maxloglik4-maxloglik3)
LRT5 = 2*(maxloglik5-maxloglik4)

1-fcdf(LRT2,1, 125-2)
1-fcdf(LRT3,1, 125-3)
1-fcdf(LRT4/4,4, 125-7)
1-fcdf(LRT5/4,4, 125-11)
