function [c, ceq, gradc, gradceq]  = comp_mu_constraints(param, y, xx)
% evaluate mean constraints and gradient of mean constraints
% for COMP_mu regression models

% no inequality constraints
c = [] ;

% dimension of problem
n = length(y) ;
q = size(xx,2) ;

% read in parameters
beta = param(1:q) ;
lambda = param(q+1:q+n) ;
nu = param(q+n+1) ;

% compute mean constraints
desired_means = exp(xx*beta) ;
current_means = comp_means(lambda, nu) ;
ceq = desired_means - current_means ;

% compute gradients of mean constraints, if requested
if nargout > 2
    gradc = [] ;
    gradbeta = xx'*diag(desired_means); %q x n
    gradlambda = diag(-comp_variances(lambda, nu)./lambda) ; %n x n
    gradnu = (comp_mean_ylogfactorialy(lambda, nu) - current_means.*comp_mean_logfactorialy(lambda, nu))'; % 1 x n
    gradceq = [gradbeta; gradlambda; gradnu] ;
end