function [negloglik, gradl] = comp_mu_loglik(param, y, xx)
% compute negative loglikelihood for COMP-mu regression models
% y is a n*1 column vector
% xx is a n*q design matrix, including intercept

n = length(y) ;
q = size(xx, 2) ;

% regression coefficients
%beta = param(1:q) ; % not needed in loglikelihood

% lambdas
lambda = param(q+1: q+n) ;

% dispersion parameter
nu = param(q+n+1) ;

% precompute quantities used later
logfactorialy = gammaln(y+1) ;
Zs = Z(lambda, nu) ;
meanlogfactorialy = comp_mean_logfactorialy(lambda, nu) ;

% compute negative loglikelihood and gradient
negloglik = - sum(y.*log(lambda) - nu*logfactorialy - log(Zs)) ;
gradl = -[zeros(q,1); y./lambda - comp_means(lambda, nu)./lambda; sum(-logfactorialy + meanlogfactorialy)] ; 
end